==> vci-0.2.5.tar.gz: vci-0.2.5/CHANGELOG.md <==
# Change Log

The format is based on [Keep a Changelog](http://keepachangelog.com/).

## [Unreleased]
### Added
- ...

### Changed
- ...

## [0.2.5] - 2020-06-27
### Changed
- [infra] update yaml calls to avoid deprecated positional args in .load()

## [0.2.4] - 2018-12-28
### Changed
- [infra] argparse dependency for python3 dropped

## [0.2.2] - 2018-12-28
### Changed
- [infra] pypi fixes

## [0.2.1] - 2018-12-28
### Added
- [infra] upgraded for python3

### Changed
- [infra] dropped unnecessary vcstool dependency

## [0.1.7] - 2017-02-15
### Changed
- [config] --set becomes a regular positional argument

## [0.1.6] - 2017-02-06
### Added
- [infra] package renamed from vcs_extras->vci

## [0.1.5] - 2017-02-05
### Added
- [infra] version option added

### Changed
- [find] bugfix lookup from method calls

## [0.1.4] - 2017-02-01
### Changed
- [config, list] --no-colour option added

## [0.1.3] - 2017-02-01
### Changed
- [find,list] added --index override functionality

## [0.1.2] - 2017-01-24
### Changed
- [find] library methods for retrieving the yaml contents
- [list] catch and log errors when the index cannot be found

## [0.1.1] - 2017-01-23
### Added
- [docs] changelog added

## [0.1.0] - 2017-01-23
### Added
- [find] parse the index and generate the .repos text to feed to vcs
- [list] list the contents of the index
- [config] set, set-default or just display the current index url

[Unreleased]: https://github.com/stonier/vci/compare/0.1.7...HEAD
[0.1.7]: https://github.com/stonier/vci/compare/0.1.6...0.1.7
[0.1.6]: https://github.com/stonier/vci/compare/0.1.5...0.1.6
[0.1.5]: https://github.com/stonier/vci/compare/0.1.4...0.1.5
[0.1.4]: https://github.com/stonier/vci/compare/0.1.3...0.1.4
[0.1.3]: https://github.com/stonier/vci/compare/0.1.2...0.1.3
[0.1.2]: https://github.com/stonier/vci/compare/0.1.1...0.1.2
[0.1.1]: https://github.com/stonier/vci/compare/0.1.0...0.1.1
[0.1.0]: https://github.com/stonier/vci/compare/c838ad46f0ffde6a9d030cbf0c91653bf5fd48e6...0.1.0

==> vci-0.2.8.tar.gz: vci-0.2.8/CHANGELOG.md <==
# Change Log

The format is based on [Keep a Changelog](http://keepachangelog.com/).

## [Unreleased]
* ...

## [0.2.8] - 2021-04-01
- [list] fallback to yaml < v5.1 Loader api on older platforms

## [0.2.6] - 2021-03-31
- [list] bugfix erroneous urllib2 exception type
- [infra] remove the reverse version dependency in setup.py
- [infra] update the venv scripts

## [0.2.5] - 2020-06-27
- [infra] update yaml calls to avoid deprecated positional args in .load()

## [0.2.4] - 2018-12-28
- [infra] argparse dependency for python3 dropped

## [0.2.2] - 2018-12-28
- [infra] pypi fixes

## [0.2.1] - 2018-12-28
- [infra] upgraded for python3
- [infra] dropped unnecessary vcstool dependency

## [0.1.7] - 2017-02-15
- [config] --set becomes a regular positional argument

## [0.1.6] - 2017-02-06
- [infra] package renamed from vcs_extras->vci

## [0.1.5] - 2017-02-05
- [infra] version option added
- [find] bugfix lookup from method calls

## [0.1.4] - 2017-02-01
- [config, list] --no-colour option added

## [0.1.3] - 2017-02-01
- [find,list] added --index override functionality

## [0.1.2] - 2017-01-24
- [find] library methods for retrieving the yaml contents
- [list] catch and log errors when the index cannot be found

## [0.1.1] - 2017-01-23
- [docs] changelog added

## [0.1.0] - 2017-01-23
- [find] parse the index and generate the .repos text to feed to vcs
- [list] list the contents of the index
- [config] set, set-default or just display the current index url

[Unreleased]: https://github.com/stonier/vci/compare/0.2.8...HEAD
[0.2.8]: https://github.com/stonier/vci/compare/0.2.6...0.2.8
[0.2.6]: https://github.com/stonier/vci/compare/0.2.5...0.2.6
[0.2.5]: https://github.com/stonier/vci/compare/0.2.4...0.2.5
[0.2.4]: https://github.com/stonier/vci/compare/0.2.2...0.2.4
[0.2.2]: https://github.com/stonier/vci/compare/0.2.1...0.2.2
[0.2.1]: https://github.com/stonier/vci/compare/0.1.7...0.2.1
[0.1.7]: https://github.com/stonier/vci/compare/0.1.6...0.1.7
[0.1.6]: https://github.com/stonier/vci/compare/0.1.5...0.1.6
[0.1.5]: https://github.com/stonier/vci/compare/0.1.4...0.1.5
[0.1.4]: https://github.com/stonier/vci/compare/0.1.3...0.1.4
[0.1.3]: https://github.com/stonier/vci/compare/0.1.2...0.1.3
[0.1.2]: https://github.com/stonier/vci/compare/0.1.1...0.1.2
[0.1.1]: https://github.com/stonier/vci/compare/0.1.0...0.1.1
[0.1.0]: https://github.com/stonier/vci/compare/c838ad46f0ffde6a9d030cbf0c91653bf5fd48e6...0.1.0
